@@ -65,7 +65,7 @@ static PyObject* transform_fn = NULL;
 static PyObject* transform(PVector* self, PyObject* args) {
   if(transform_fn == NULL) {
     // transform to avoid circular import problems
-    transform_fn = PyObject_GetAttrString(PyImport_ImportModule("pyrsistent"), "_transform");
+    transform_fn = PyObject_GetAttrString(PyImport_ImportModule("pyrsistent._transformations"), "transform");
   }
 
   return PyObject_CallFunctionObjArgs(transform_fn, self, args, NULL);
@@ -365,7 +365,7 @@ static PyObject* PVector_richcompare(PyObject *v, PyObject *w, int op) {
             return NULL;
         }
         if (!k) {
-            break;
+           break;
         }
     }
 
@@ -548,8 +548,6 @@ static PyObject* PVector_append(PVector *self, PyObject *obj);
 
 static PyObject* PVector_transform(PVector *self, PyObject *obj);
 
-static PyObject* PVector_set_in(PVector *self, PyObject *obj);
-
 static PyObject* PVector_set(PVector *self, PyObject *obj);
 
 static PyObject* PVector_mset(PVector *self, PyObject *args);
@@ -584,7 +582,6 @@ static PyMethodDef PVector_methods[] = {
 	{"set",         (PyCFunction)PVector_set, METH_VARARGS, "Inserts an element at the specified position"},
 	{"extend",      (PyCFunction)PVector_extend, METH_O|METH_COEXIST, "Extend"},
         {"transform",   (PyCFunction)PVector_transform, METH_VARARGS, "Apply one or more transformations"},
-        {"set_in",      (PyCFunction)PVector_set_in, METH_VARARGS, "Set in"},
         {"index",       (PyCFunction)PVector_index, METH_VARARGS, "Return first index of value"},
 	{"count",       (PyCFunction)PVector_count, METH_O, "Return number of occurrences of value"},
         {"__reduce__",  (PyCFunction)PVector_pickle_reduce, METH_NOARGS, "Pickle support method"},
@@ -967,10 +964,6 @@ static PyObject* PVector_transform(PVector *self, PyObject *obj) {
   return transform(self, obj);
 }
 
-static PyObject* PVector_set_in(PVector *self, PyObject *obj) {
-  return transform(self, obj);
-}
-
 /*
  Steals a reference to the object that is inserted in the vector.
 */
@@ -1009,7 +1002,12 @@ static PyObject* PVector_mset(PVector *self, PyObject *args) {
 
 
 static PyMethodDef PyrsistentMethods[] = {
-  {"pvector", pyrsistent_pvec, METH_VARARGS, "Factory method for persistent vectors"},
+  {"pvector", pyrsistent_pvec, METH_VARARGS, 
+   "pvector([iterable])\n"
+   "Create a new persistent vector containing the elements in iterable.\n\n"
+   ">>> v1 = pvector([1, 2, 3])\n"
+   ">>> v1\n"
+   "pvector([1, 2, 3])"},
   {NULL, NULL, 0, NULL}
 };
 
@@ -1250,7 +1248,7 @@ static PyTypeObject PVectorEvolverType = {
 
 
 static void cleanNodeRecursively(VNode *node, int level) {
-  debug("Freezing recursively node=%p, level=%u\n", node, level);
+  debug("Cleaning recursively node=%p, level=%u\n", node, level);
 
   int i;
   CLEAR_DIRTY(node);
@@ -1266,9 +1264,9 @@ static void cleanNodeRecursively(VNode *node, int level) {
 }
 
 static void cleanVector(PVector *vector) {
-  // Freezing the vector means that all dirty indications are cleared
+  // Cleaning the vector means that all dirty indications are cleared
   // and that the nodes that were dirty get a ref count of 1 since
-  // they are brand new. Once frozen the vector can be released into
+  // they are brand new. Once cleaned the vector can be released into
   // the wild.
   if(IS_DIRTY(vector->tail)) {
     cleanNodeRecursively(vector->tail, 0);
